import { Store } from "@willsoto/node-konfig-core";
import { decodeBase64, encodeBase64 } from "jsr:@std/encoding/base64";
import { Aes } from "https://deno.land/x/crypto@v0.10.1/aes.ts";
import {
    Ecb,
    Padding,
} from "https://deno.land/x/crypto@v0.10.1/block-modes.ts";

export const encryptQuery = (
    queryParams: string,
    konfigStore: Store,
): string => {
    try {
        const cipher = new Ecb(
            Aes,
            new TextEncoder().encode((
                Deno.env.get("SERVER_SECRET_KEY") ||
                konfigStore.get("server.secret_key") as string
            ).substring(0, 16)),
            Padding.PKCS7,
        );

        const encodedData = new TextEncoder().encode(
            queryParams
        );

		const encryptedData = cipher.encrypt(encodedData)

		return encodeBase64(encryptedData).replace(/\+/g, "-").replace(/\//g, "_")
    } catch (_) {
		return ""
    }
};

export const decryptQuery = (
    queryParams: string,
    konfigStore: Store,
): string => {
    try {
        const decipher = new Ecb(
            Aes,
            new TextEncoder().encode((
                Deno.env.get("SERVER_SECRET_KEY") ||
                konfigStore.get("server.secret_key") as string
            ).substring(0, 16)),
            Padding.PKCS7,
        );

        const decryptedData = new TextDecoder().decode(
            decipher.decrypt(
                decodeBase64(
                    queryParams.replace(/-/g, "+").replace(/_/g, "/"),
                ),
            ),
        );

		return decryptedData
    } catch (_) {
		return ""
    }
};